@@ -1,6 +1,6 @@
 ;;; hibtypes.el --- Hyperbole System Implicit Button Types.
 
-;; Copyright (C) 2004 Free Software Foundation, Inc.
+;; Copyright (C) 2004, 2008 Free Software Foundation, Inc.
 ;; Developed with support from Motorola Inc.
 
 ;; Author: Bob Weiner, Brown U.
@@ -293,7 +293,7 @@ This works with gdb, dbx, and xdb.  Such lines are recognized in any buffer."
 		  (line-num (buffer-substring (match-beginning 3)
 					      (match-end 3)))
 		  (but-label (concat file ":" line-num)))
-	     (setq line-num (string-to-int line-num))
+	     (setq line-num (string-to-number line-num))
 	     (ibut:label-set but-label)
 	     (hact 'link-to-file-line file line-num)))
 	   ((looking-at ".+ (file=[^\"\n]+\"\\([^\"\n]+\\)\", line=\\([0-9]+\\),")
@@ -303,7 +303,7 @@ This works with gdb, dbx, and xdb.  Such lines are recognized in any buffer."
 		  (line-num (buffer-substring (match-beginning 2)
 					      (match-end 2)))
 		  (but-label (concat file ":" line-num)))
-	     (setq line-num (string-to-int line-num))
+	     (setq line-num (string-to-number line-num))
 	     (ibut:label-set but-label)
 	     (hact 'link-to-file-line file line-num)))
 	  ((looking-at ".+ line \\([0-9]+\\) in \"\\([^\"]+\\)\"$")
@@ -313,7 +313,7 @@ This works with gdb, dbx, and xdb.  Such lines are recognized in any buffer."
 		  (line-num (buffer-substring (match-beginning 1)
 					      (match-end 1)))
 		  (but-label (concat file ":" line-num)))
-	     (setq line-num (string-to-int line-num))
+	     (setq line-num (string-to-number line-num))
 	     (ibut:label-set but-label)
 	     (hact 'link-to-file-line file line-num)))
 	  ((or (looking-at ".+ \\[\"\\([^\"]+\\)\":\\([0-9]+\\),") ;; Old DBX
@@ -323,7 +323,7 @@ This works with gdb, dbx, and xdb.  Such lines are recognized in any buffer."
 		  (line-num (buffer-substring (match-beginning 2)
 					      (match-end 2)))
 		  (but-label (concat file ":" line-num)))
-	     (setq line-num (string-to-int line-num))
+	     (setq line-num (string-to-number line-num))
 	     (ibut:label-set but-label)
 	     (hact 'link-to-file-line file line-num))))))
 
@@ -379,7 +379,7 @@ Messages are recognized in any buffer."
 	    (if (stringp source-loc)
 		(setq file (expand-file-name
 			    file (file-name-directory source-loc))))
-	    (setq line-num (string-to-int line-num))
+	    (setq line-num (string-to-number line-num))
 	    (ibut:label-set but-label)
 	    (hact 'link-to-file-line file line-num))))))
 
@@ -447,7 +447,7 @@ Patch applies diffs to source code."
 	(goto-char opoint)
 	(if (null file)
 	    nil
-	  (setq line (string-to-int line))
+	  (setq line (string-to-number line))
 	  (hact 'link-to-file-line file line)))))
 
 ;;;
